braindecode.datautil.zscore
===========================

.. currentmodule:: braindecode.datautil

.. autofunction:: zscore

.. include:: braindecode.datautil.zscore.examples

.. raw:: html

    <div style='clear:both'></div>